
import os, pytest
from lib389.ds_instance import DSModuleProxy

def test_add_repl_manager(fake_ds_inst_with_repl):
    ds_inst = fake_ds_inst_with_repl
    ds_inst.repl.add_repl_manager("cn=replication manager, cn=config", "Secret123")
    assert ds_inst.dit["cn=replication manager, cn=config"]["userPassword"] == "Secret123"
    assert ds_inst.dit["cn=replication manager, cn=config"]["nsIdleTimeout"] == "0"
    assert ds_inst.dit["cn=replication manager, cn=config"]["cn"] == "replication manager"

def test_changelog(fake_ds_inst_with_repl):
    # Test enable_changelog with default value for changelogmaxage
    ds_inst = fake_ds_inst_with_repl
    ds_inst.repl.enable_changelog("/path/to/my/changelog")
    assert ds_inst.dit["cn=changelog5,cn=config"]["nsslapd-changelogdir"] == "/path/to/my/changelog"
    assert ds_inst.dit["cn=changelog5,cn=config"]["nsslapd-changelogmaxage"] == "10dc"

    # Test disable_changelog - verify that entry cn=changelog5,cn=config was deleted
    ds_inst.repl.disable_changelog()
    with pytest.raises(KeyError):
        ds_inst.dit["cn=changelog5,cn=config"]

    # Test enable_changelog with custom value for changelogmaxage
    ds_inst.repl.enable_changelog("/path/to/my/other/changelog", changelogmaxage="11dc")
    assert ds_inst.dit["cn=changelog5,cn=config"]["nsslapd-changelogdir"] == "/path/to/my/other/changelog"
    assert ds_inst.dit["cn=changelog5,cn=config"]["nsslapd-changelogmaxage"] == "11dc"
